@@ -157,7 +157,7 @@ class Model:
     filename : str
             Name for the model. Saved data will be saved under this name.
     initial_frequency_hz : float, optional
-            Initial frequency for the waveforms, by default 20.0
+            Initial frequency for the waveforms, by default 5.0
     srate_hz : float, optional
             Time-domain signal rate for the waveforms,
             which is twice the maximum frequency of
@@ -196,7 +196,7 @@ class Model:
     def __init__(
         self,
         filename: Optional[str] = None,
-        initial_frequency_hz: float = 20.0,
+        initial_frequency_hz: float = 5.0,
         srate_hz: float = 4096.0,
         pca_components_number: int = 30,
         multibanding: bool = True,
@@ -809,8 +809,9 @@ class Model:
             Time or times left until merger.
         """
 
-        df = frequency / 1000
-        freqs = frequency + df * np.arange(-4, 5)
+        if delta_f is None:
+            delta_f = frequency / 1000
+        freqs = frequency + delta_f * np.arange(-4, 5)
         weights = np.array([3, -32, 168, -672, 0, 672, -168, 32, -3]) / 840.0
 
         try:
@@ -822,7 +823,7 @@ class Model:
                 params.intrinsic(self.dataset), freqs * params.mass_sum_seconds
             )
 
-        derivative = np.sum(phis * weights) / df
+        derivative = np.sum(phis * weights) / delta_f
 
         return derivative / (2 * np.pi)
 
